@@ -21,6 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -311,7 +313,7 @@ spi_display_name (void)
 		canonical_display_name = g_strdup (display_env);
 		display_p = strrchr (canonical_display_name, ':');
 		screen_p = strrchr (canonical_display_name, '.');
-		if (screen_p && display_p && ((guint) screen_p > (guint) display_p))
+		if (screen_p && display_p && (screen_p > display_p))
 		{
 		    *screen_p = '\0';
 		}
@@ -589,7 +591,6 @@ spi_atk_bridge_focus_tracker (AtkObject *object)
 {
   SpiAccessible *source;
   Accessibility_Event e;
-  const gchar *name = atk_object_get_name (object);
   
   source = spi_accessible_new (object);
   
@@ -694,7 +695,7 @@ spi_atk_emit_eventv (const GObject         *gobject,
   
   g_free (e.type);
 
-  if (e.any_data._release) CORBA_free (&e.any_data._value);
+  if (!any && e.any_data._release) CORBA_free (e.any_data._value);
   
   va_end (args);
 
